@@ -5,7 +5,6 @@
 #'
 #' @docType package
 #' @name dtwclust-package
-#' @include utils.R
 #'
 #' @details
 #'
@@ -59,141 +58,35 @@
 #' [tsclust()], [compare_clusterings()], [proxy::dist()], [dtw::dtw()]
 #'
 #' @useDynLib dtwclust, .registration = TRUE
-#'
 #' @import foreach
-#'
-#' @importFrom bigmemory attach.big.matrix
-#' @importFrom bigmemory big.matrix
-#' @importFrom bigmemory describe
-#' @importFrom bigmemory is.big.matrix
-#'
-#' @importFrom clue as.cl_class_ids
-#' @importFrom clue as.cl_membership
-#' @importFrom clue cl_class_ids
-#' @importFrom clue cl_membership
-#' @importFrom clue is.cl_dendrogram
-#' @importFrom clue is.cl_hard_partition
-#' @importFrom clue is.cl_hierarchy
-#' @importFrom clue is.cl_partition
-#' @importFrom clue n_of_classes
-#' @importFrom clue n_of_objects
-#'
-#' @importFrom dtw dtw
-#' @importFrom dtw symmetric1
-#' @importFrom dtw symmetric2
-#'
-#' @importFrom flexclust clusterSim
-#' @importFrom flexclust comPart
-#' @importFrom flexclust randIndex
-#'
-#' @importFrom ggplot2 aes_string
-#' @importFrom ggplot2 facet_wrap
-#' @importFrom ggplot2 geom_line
-#' @importFrom ggplot2 geom_vline
-#' @importFrom ggplot2 ggplot
-#' @importFrom ggplot2 guides
-#' @importFrom ggplot2 labs
-#' @importFrom ggplot2 theme_bw
-#'
-#' @importFrom graphics plot
-#'
-#' @importClassesFrom Matrix sparseMatrix
-#' @importFrom Matrix forceSymmetric
-#' @importFrom Matrix rowSums
-#' @importFrom Matrix sparseMatrix
-#' @importFrom Matrix summary
-#'
-#' @importFrom methods S3Part
-#' @importFrom methods as
-#' @importFrom methods callNextMethod
-#' @importFrom methods initialize
-#' @importFrom methods new
-#' @importFrom methods setAs
-#' @importFrom methods setClass
-#' @importFrom methods setClassUnion
-#' @importFrom methods setGeneric
-#' @importFrom methods setValidity
-#' @importFrom methods show
-#' @importFrom methods signature
-#' @importFrom methods slot
-#' @importFrom methods slot<-
-#' @importFrom methods slotNames
-#' @importFrom methods validObject
-#'
-#' @importFrom parallel splitIndices
-#'
-#' @importFrom plyr rbind.fill
-#'
-#' @importFrom proxy dist
-#' @importFrom proxy pr_DB
-#'
-#' @importFrom RSpectra eigs_sym
-#'
 #' @importFrom Rcpp evalCpp
 #'
-#' @importFrom reshape2 melt
-#'
-#' @importFrom rngtools RNGseq
-#' @importFrom rngtools setRNG
-#'
-#' @importFrom stats aggregate
-#' @importFrom stats approx
-#' @importFrom stats as.dist
-#' @importFrom stats as.hclust
-#' @importFrom stats convolve
-#' @importFrom stats cutree
-#' @importFrom stats fft
-#' @importFrom stats hclust
-#' @importFrom stats median
-#' @importFrom stats nextn
-#' @importFrom stats predict
-#' @importFrom stats runif
-#' @importFrom stats update
-#'
-#' @importFrom utils head
-#' @importFrom utils packageVersion
-#'
-NULL ## remember to check methods imports after removing dtwclust()
-
-#' Deprecated functionality in \pkg{dtwclust}
-#'
-#' @name dtwclust-deprecated
-#' @aliases dtwclust-deprecated
-#'
-#' @description
-#'
-#' The following functions and/or classes are deprecated and will be eventually removed:
-#'
-#' - [dtwclust()] - see [tsclust()]
-#' - [dtwclustFamily-class] - see [tsclustFamily-class]
-#' - [dtwclustControl-class] - see [tsclust-controls]
-#' - [dtwclust-class] - see [TSClusters-class]
-#' - [dtwclust-methods] - see [tsclusters-methods]
-#' - [randIndex()] - see [cvi()]
-#' - [clusterSim()]
-#' - [create_dtwclust()] - see [tsclusters-methods]
-#' - [compute_envelop()] - see [compute_envelope()]
-#'
 NULL
 
-.onAttach <- function(lib, pkg) {
-    ## proxy_prefun is in utils.R
+# PREFUN for some of my proxy distances so that they support 'pairwise' directly
+proxy_prefun <- function(x, y, pairwise, params, reg_entry) {
+    params$pairwise <- pairwise
+    list(x = x, y = y, pairwise = pairwise, p = params, reg_entry = reg_entry)
+}
 
-    ## Register DTW2
+#' @importFrom utils packageVersion
+#'
+.onAttach <- function(lib, pkg) {
+    # Register DTW2
     if (!check_consistency("DTW2", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = dtw2.proxy, names=c("DTW2", "dtw2"),
                                loop = TRUE, type = "metric", distance = TRUE,
                                description = "DTW with L2 norm",
                                PACKAGE = "dtwclust")
 
-    ## Register DTW_BASIC
+    # Register DTW_BASIC
     if (!check_consistency("DTW_BASIC", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = dtw_basic_proxy, names=c("DTW_BASIC", "dtw_basic"),
                                loop = FALSE, type = "metric", distance = TRUE,
                                description = "Basic and maybe faster DTW distance",
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun)
 
-    ## Register LB_Keogh
+    # Register LB_Keogh
     if (!check_consistency("LB_Keogh", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = lb_keogh_proxy, names=c("LBK", "LB_Keogh", "lbk"),
                                loop = FALSE, type = "metric", distance = TRUE,
@@ -201,14 +94,14 @@ NULL
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun)
 
 
-    ## Register LB_Improved
+    # Register LB_Improved
     if (!check_consistency("LB_Improved", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = lb_improved_proxy, names=c("LBI", "LB_Improved", "lbi"),
                                loop = FALSE, type = "metric", distance = TRUE,
                                description = "Lemire's improved DTW lower bound for the Sakoe-Chiba band",
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun)
 
-    ## Register SBD
+    # Register SBD
     if (!check_consistency("SBD", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = SBD_proxy, names=c("SBD", "sbd"),
                                loop = FALSE, type = "metric", distance = TRUE,
@@ -216,14 +109,14 @@ NULL
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun,
                                convert = function(d) { 2 - d })
 
-    ## Register DTW_LB
+    # Register DTW_LB
     if (!check_consistency("DTW_LB", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = dtw_lb, names=c("DTW_LB", "dtw_lb"),
                                loop = FALSE, type = "metric", distance = TRUE,
                                description = "DTW distance aided with Lemire's lower bound",
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun)
 
-    ## Register GAK
+    # Register GAK
     if (!check_consistency("GAK", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = GAK_proxy, names=c("GAK", "gak"),
                                loop = FALSE, type = "metric", distance = TRUE,
@@ -231,7 +124,7 @@ NULL
                                PACKAGE = "dtwclust", PREFUN = proxy_prefun,
                                convert = function(d) { 1 - d })
 
-    ## Register uGAK
+    # Register uGAK
     if (!check_consistency("uGAK", "dist", silent = TRUE))
         proxy::pr_DB$set_entry(FUN = GAK_simil, names=c("uGAK", "ugak"),
                                loop = FALSE, type = "metric", distance = FALSE,
@@ -240,20 +133,31 @@ NULL
 
     RNGkind("L'Ecuyer")
 
-    ## avoids default message if no backend exists
+    # avoids default message if no backend exists
     if (is.null(foreach::getDoParName())) foreach::registerDoSEQ()
 
-    packageStartupMessage("\ndtwclust:\n",
+    packageStartupMessage("dtwclust:\n",
                           "Setting random number generator to L'Ecuyer-CMRG (see RNGkind()).\n",
                           'To read the included vignettes type: browseVignettes("dtwclust").\n',
                           'Please see news(package = "dtwclust") for important information.')
 
     if (grepl("\\.9000$", utils::packageVersion("dtwclust")))
-        packageStartupMessage("\nThis is a developer version of 'dtwclust'.\n",
+        packageStartupMessage("This is a developer version of dtwclust:\n",
                               "Using devtools::test() is currently broken, see tests/testthat.R")
 }
 
-.onUnload <- function(libpath) { library.dynam.unload("dtwclust", libpath) }
+.onUnload <- function(libpath) {
+    # Unegister distances
+    if (check_consistency("DTW2", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("DTW2")
+    if (check_consistency("DTW_BASIC", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("DTW_BASIC")
+    if (check_consistency("LB_Keogh", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("LB_Keogh")
+    if (check_consistency("LB_Improved", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("LB_Improved")
+    if (check_consistency("SBD", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("SBD")
+    if (check_consistency("DTW_LB", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("DTW_LB")
+    if (check_consistency("GAK", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("GAK")
+    if (check_consistency("uGAK", "dist", silent = TRUE)) proxy::pr_DB$delete_entry("uGAK")
+    library.dynam.unload("dtwclust", libpath)
+}
 
 release_questions <- function() {
     c(
