@@ -10,30 +10,30 @@ extern "C" {
 #include <R_ext/Rdynload.h>
 
 SEXP dtw_basic(SEXP x, SEXP y, SEXP window,
-               SEXP m, SEXP n, SEXP dim,
+               SEXP m, SEXP n, SEXP num_var,
                SEXP norm, SEXP step, SEXP backtrack,
                SEXP distmat)
 {
     static SEXP(*fun)(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP) = NULL;
     if(fun == NULL)
         fun = (SEXP(*)(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP)) R_GetCCallable("dtwclust", "dtw_basic");
-    return fun(x, y, window, m, n, dim, norm, step, backtrack, distmat);
+    return fun(x, y, window, m, n, num_var, norm, step, backtrack, distmat);
 }
 
-SEXP logGAK(SEXP x, SEXP y, SEXP nx, SEXP ny, SEXP dim, SEXP sigma, SEXP window, SEXP logs)
+SEXP logGAK(SEXP x, SEXP y, SEXP nx, SEXP ny, SEXP num_var, SEXP sigma, SEXP window, SEXP logs)
 {
     static SEXP(*fun)(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP) = NULL;
     if(fun == NULL)
         fun = (SEXP(*)(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP)) R_GetCCallable("dtwclust", "logGAK");
-    return fun(x, y, nx, ny, dim, sigma, window, logs);
+    return fun(x, y, nx, ny, num_var, sigma, window, logs);
 }
 
-SEXP pairs(SEXP L, SEXP lower)
+SEXP pairs(SEXP L)
 {
-    static SEXP(*fun)(SEXP, SEXP) = NULL;
+    static SEXP(*fun)(SEXP) = NULL;
     if(fun == NULL)
-        fun = (SEXP(*)(SEXP, SEXP)) R_GetCCallable("dtwclust", "pairs");
-    return fun(L, lower);
+        fun = (SEXP(*)(SEXP)) R_GetCCallable("dtwclust", "pairs");
+    return fun(L);
 }
 
 SEXP setnames_inplace(SEXP vec, SEXP names)
