@@ -1,53 +1,33 @@
 context("\tFamilies and proxy distances")
 
-# =================================================================================================
+# ==================================================================================================
 # setup
-# =================================================================================================
+# ==================================================================================================
 
 ## Original objects in env
 ols <- ls()
 
-ctrl <- new("dtwclustControl", window.size = 18L)
 ts_ctrl <- partitional_control()
 x <- data_reinterpolated_subset
 centroids <- x[c(1L, 15L)]
 attr(centroids, "id_cent") <- c(1L, 15L)
+window.size <- 18L
 
 # ==================================================================================================
 # lbk
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
-    distmat <- proxy::dist(x, x, method = "lbk", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "lbk")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and lbk give expected results", {
+    distmat <- proxy::dist(x, x, method = "lbk", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "lbk")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -60,21 +40,6 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "lbk")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -83,8 +48,8 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
                   control = ts_ctrl,
                   dist = "lbk")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -100,7 +65,7 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
     dm <- dtwclust:::SparseDistmat$new(series = x,
                                        control = ts_ctrl,
                                        distance = "lbk",
-                                       dist_args = list(window.size = ctrl@window.size),
+                                       dist_args = list(window.size = window.size),
                                        id_cent = attr(centroids, "id_cent"))
     ts_ctrl$distmat <- dm
 
@@ -122,37 +87,17 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
 # lbi
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
-    distmat <- proxy::dist(x, x, method = "lbi", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "lbi")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and lbi give expected results", {
+    distmat <- proxy::dist(x, x, method = "lbi", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "lbi")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -165,21 +110,6 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "lbi")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -188,8 +118,8 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
                   control = ts_ctrl,
                   dist = "lbi")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -205,7 +135,7 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
     dm <- dtwclust:::SparseDistmat$new(series = x,
                                        control = ts_ctrl,
                                        distance = "lbi",
-                                       dist_args = list(window.size = ctrl@window.size),
+                                       dist_args = list(window.size = window.size),
                                        id_cent = attr(centroids, "id_cent"))
     ts_ctrl$distmat <- dm
 
@@ -227,29 +157,9 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
 # sbd
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and sbd give expected results", {
+test_that("Operations with tsclustFamily@dist and sbd give expected results", {
     distmat <- proxy::dist(x, x, method = "sbd")
 
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "sbd")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -270,21 +180,6 @@ test_that("Operations with dtwclustFamily@dist and sbd give expected results", {
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "sbd")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -332,36 +227,18 @@ test_that("Operations with dtwclustFamily@dist and sbd give expected results", {
 # dtw_lb
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and dtw_lb give expected results", {
-    distmat <- proxy::dist(x, x, method = "dtw_lb", window.size = ctrl@window.size)
-    sdm <- proxy::dist(x, centroids, method = "dtw_lb", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "dtw_lb")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, sdm, tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and dtw_lb give expected results", {
+    distmat <- proxy::dist(x, x, method = "dtw_lb", window.size = window.size)
+    sdm <- proxy::dist(x, centroids, method = "dtw_lb", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "dtw_lb")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
 
     expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
@@ -372,21 +249,6 @@ test_that("Operations with dtwclustFamily@dist and dtw_lb give expected results"
 
     expect_equal(sub_distmat, sdm, tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "dtw_lb")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -395,8 +257,8 @@ test_that("Operations with dtwclustFamily@dist and dtw_lb give expected results"
                   control = ts_ctrl,
                   dist = "dtw_lb")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -414,39 +276,17 @@ test_that("Operations with dtwclustFamily@dist and dtw_lb give expected results"
 # dtw
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and dtw give expected results", {
-    skip_on_cran()
-
-    distmat <- proxy::dist(x, x, method = "dtw", window.type = "slantedband", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "dtw")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and dtw give expected results", {
+    distmat <- proxy::dist(x, x, method = "dtw", window.type = "slantedband", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "dtw")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -459,21 +299,6 @@ test_that("Operations with dtwclustFamily@dist and dtw give expected results", {
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "dtw")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -482,8 +307,8 @@ test_that("Operations with dtwclustFamily@dist and dtw give expected results", {
                   control = ts_ctrl,
                   dist = "dtw")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -499,39 +324,17 @@ test_that("Operations with dtwclustFamily@dist and dtw give expected results", {
 # dtw2
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and dtw2 give expected results", {
-    skip_on_cran()
-
-    distmat <- proxy::dist(x, x, method = "dtw2", window.type = "slantedband", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "dtw2")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and dtw2 give expected results", {
+    distmat <- proxy::dist(x, x, method = "dtw2", window.type = "slantedband", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "dtw2")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -544,21 +347,6 @@ test_that("Operations with dtwclustFamily@dist and dtw2 give expected results",
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "dtw2")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -567,8 +355,8 @@ test_that("Operations with dtwclustFamily@dist and dtw2 give expected results",
                   control = ts_ctrl,
                   dist = "dtw2")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -584,37 +372,17 @@ test_that("Operations with dtwclustFamily@dist and dtw2 give expected results",
 # dtw_basic
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and dtw_basic give expected results", {
-    distmat <- proxy::dist(x, x, method = "dtw_basic", window.size = ctrl@window.size)
-
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "dtw_basic")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-    pdist <- family@dist(x, pairwise = TRUE)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
+test_that("Operations with tsclustFamily@dist and dtw_basic give expected results", {
+    distmat <- proxy::dist(x, x, method = "dtw_basic", window.size = window.size)
 
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "dtw_basic")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -627,21 +395,6 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "dtw_basic")
-
-    whole_distmat <- family@dist(x)
-    sub_distmat <- family@dist(x, centroids)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -650,8 +403,8 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
                   control = ts_ctrl,
                   dist = "dtw_basic")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size)
+    whole_distmat <- family@dist(x, window.size = window.size)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -667,7 +420,7 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
     dm <- dtwclust:::SparseDistmat$new(series = x,
                                        control = ts_ctrl,
                                        distance = "dtw_basic",
-                                       dist_args = list(window.size = ctrl@window.size),
+                                       dist_args = list(window.size = window.size),
                                        id_cent = attr(centroids, "id_cent"))
     ts_ctrl$distmat <- dm
 
@@ -689,39 +442,19 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
 # gak
 # ==================================================================================================
 
-test_that("Operations with dtwclustFamily@dist and gak give expected results", {
+test_that("Operations with tsclustFamily@dist and gak give expected results", {
     distmat <- proxy::dist(x, x, method = "gak",
-                           window.size = ctrl@window.size,
+                           window.size = window.size,
                            sigma = 100)
 
-    ## ---------------------------------------------------------- dtwclustFamily, no distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  dist = "gak")
-
-    whole_distmat <- family@dist(x, sigma = 100)
-    sub_distmat <- family@dist(x, centroids, sigma = 100)
-    pdist <- family@dist(x, pairwise = TRUE, sigma = 100)
-    class(pdist) <- NULL
-    class(sub_distmat) <- "matrix"
-
-    expect_equal(pdist, rep(0, length(pdist)), info = "Pairwise",
-                 check.attributes = FALSE)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, no distmat
     family <- new("tsclustFamily",
                   control = ts_ctrl,
                   dist = "gak")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size, sigma = 100)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size, sigma = 100)
-    pdist <- family@dist(x, window.size = ctrl@window.size, pairwise = TRUE, sigma = 100)
+    whole_distmat <- family@dist(x, window.size = window.size, sigma = 100)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size, sigma = 100)
+    pdist <- family@dist(x, window.size = window.size, pairwise = TRUE, sigma = 100)
     class(pdist) <- NULL
     class(sub_distmat) <- "matrix"
 
@@ -734,21 +467,6 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
     expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, NULL distmat",
                  tolerance = 0, check.attributes = FALSE)
 
-    ## ---------------------------------------------------------- dtwclustFamily, with distmat
-    family <- new("dtwclustFamily",
-                  control = ctrl,
-                  distmat = distmat,
-                  dist = "gak")
-
-    whole_distmat <- family@dist(x, sigma = 100)
-    sub_distmat <- family@dist(x, centroids, sigma = 100)
-
-    expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
-    expect_equal(sub_distmat, distmat[ , c(1L, 15L), drop = FALSE], info = "Sub, with distmat",
-                 tolerance = 0, check.attributes = FALSE)
-
     ## ---------------------------------------------------------- tsclustFamily, with distmat
     ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
                                               id_cent = attr(centroids, "id_cent"))
@@ -757,8 +475,8 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
                   control = ts_ctrl,
                   dist = "gak")
 
-    whole_distmat <- family@dist(x, window.size = ctrl@window.size, sigma = 100)
-    sub_distmat <- family@dist(x, centroids, window.size = ctrl@window.size, sigma = 100)
+    whole_distmat <- family@dist(x, window.size = window.size, sigma = 100)
+    sub_distmat <- family@dist(x, centroids, window.size = window.size, sigma = 100)
 
     expect_equal(whole_distmat, distmat, info = "Whole, with distmat",
                  tolerance = 0, check.attributes = FALSE)
@@ -774,7 +492,7 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
     dm <- dtwclust:::SparseDistmat$new(series = x,
                                        control = ts_ctrl,
                                        distance = "gak",
-                                       dist_args = list(window.size = ctrl@window.size,
+                                       dist_args = list(window.size = window.size,
                                                         sigma = 100),
                                        id_cent = attr(centroids, "id_cent"))
     ts_ctrl$distmat <- dm
@@ -793,7 +511,8 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
                  info = "Sub, sparse distmat", tolerance = 0, check.attributes = FALSE)
 })
 
-# =================================================================================================
+# ==================================================================================================
 # clean
-# =================================================================================================
+# ==================================================================================================
+
 rm(list = setdiff(ls(), ols))
